==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/content/messages/id/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Juga tersedia untuk bukan anggota group ini)',
    '<strong>Confirm</strong> post deletion' => '<strong>Konfirmasi</strong> hapus post',
    '<strong>Delete</strong> content?' => '<strong>Hapus</strong> konten?',
    '<strong>Move</strong> content' => '<strong>Pindah</strong> konten',
    '<strong>Permalink</strong> to this post' => '<strong>Link Unik</strong> post ini',
    'Add a member to notify' => 'Tambah pemberitahuan anggota',
    'Add tag...' => 'Tambah tag...',
    'Archived' => 'Arsip',
    'Attach Files' => 'Unggah berkas',
    'Back to stream' => 'Kembali ke feed',
    'Cancel' => 'Batal',
    'Cancel Edit' => 'Batal Ubah',
    'Change to "Private"' => 'Buat privat',
    'Change to "Public"' => 'Buat publik',
    'Comments are locked' => 'Komentar dikunci',
    'Comments are unlocked' => 'Komentar dibuka',
    'Configure' => 'Konfigurasi',
    'Confirm' => 'Konfirmasi',
    'Content' => 'Konten',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Tag Konten dengan contentcontainer_id yang tidak valid ditetapkan.',
    'Content has been moved to {spacename}' => 'Konten pindah ke {spacename}',
    'Could not find requested content!' => 'Tidak menemukan konten itu',
    'Created at:' => 'Dibuat pada:',
    'Created by me' => 'Dibuat oleh saya',
    'Creation time' => 'Waktu dibuat',
    'Delete' => 'Hapus',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'Yakin mau menghapus post ini? Semua suka dan komentar akan hilang!',
    'Edit' => 'Ubah',
    'Enable' => 'Aktifkan',
    'Filter' => 'Filter',
    'I\'m involved' => 'Ada saya',
    'Invalid content id given!' => 'ID konten yang diberikan tidak valid!',
    'Invalid request method!' => 'Kesalahan metode permintaan!',
    'Invalid space selection.' => 'Pilihan ruang tidak valid.',
    'Last update' => 'Update terakhir',
    'Last updated {time}' => 'Update terakhir {time}',
    'Load more' => 'Buka lagi',
    'Lock comments' => 'Kunci komentar',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Jumlah maksimum item yang disematkan tercapai!<br>Anda hanya dapat menyematkan hingga {count} item sekaligus.',
    'Move content' => 'Pindah konten',
    'Move to archive' => 'Pindahkan ke arsip',
    'New Updates Available!' => 'Tersedia Pembaruan Baru!',
    'No matches with your selected filters!' => 'Tidak ada yang cocok dengan filter pilihan Anda!',
    'No tags found for the given query' => 'Tidak ada tag yang ditemukan untuk kueri yang diberikan',
    'None' => 'Tidak ada',
    'Nothing here yet!' => 'Belum ada apa-apa di sini!',
    'Notify members' => 'Beritahu anggota',
    'Permalink' => '@@@@',
    'Pin to top' => 'Sematkan ke atas',
    'Pinned' => 'Disematkan',
    'Private' => 'Pribadi',
    'Public' => 'Publik',
    'Select type...' => 'Pilih tipe...',
    'Specify who can see this content.' => 'Tentukan siapa saja yang dapat melihat konten ini.',
    'Submit' => 'Kirim',
    'Tag' => 'Tag',
    'Target Space' => 'Ruang Sasaran',
    'The author of this content is not allowed to create private content within the selected space.' => 'Penulis konten ini tidak diperbolehkan membuat konten pribadi di dalam ruang yang dipilih.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Penulis konten ini tidak diperbolehkan membuat konten publik di dalam ruang yang dipilih.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Pembuat konten ini tidak diizinkan membuat jenis konten ini di ruang ini.',
    'The content can\'t be moved to its current space.' => 'Konten tidak dapat dipindahkan ke ruangnya saat ini.',
    'The content has been archived.' => 'Konten tersebut telah diarsipkan.',
    'The content has been deleted.' => 'Konten telah dihapus.',
    'The content has been unarchived.' => 'Konten telah dibatalkan pengarsipannya.',
    'This action is disabled!' => 'Untuk aksi ini dinonaktifkan',
    'This space is archived.' => 'Ruang ini di arsipkan',
    'Unarchive' => 'arsipkan',
    'Updated' => 'Perbarui',
    'in' => 'pada',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Activated' => '',
    'Cannot notify the author.' => '',
    'Create as draft' => '',
    'Deleted' => '',
    'Draft' => '',
    'Hidden' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Schedule publication' => '',
    'Scheduled at {dateTime}' => '',
    'The content has been successfully published.' => '',
    'The given name is already in use.' => '',
    'The module {moduleName} is not enabled on the selected target space.' => '',
    'This content type can\'t be moved due to a missing module-id setting.' => '',
    'This content type can\'t be moved.' => '',
    'This space is not visible!' => '',
    'Topics' => '',
    'Turn off notifications' => '',
    'Turn on notifications' => '',
    'Unlock comments' => '',
    'Unpin' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'With attachments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
    'You do not have the permission to move this content to the given space.' => '',
    'You do not have the permission to move this content.' => '',
    'Your last edit state has been saved!' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/id/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Juga tersedia untuk bukan anggota group ini)',
    '<strong>Delete</strong> content?' => '<strong>Hapus</strong> konten?',
    '<strong>Move</strong> content' => '<strong>Pindah</strong> konten',
    '<strong>Permalink</strong> to this post' => '<strong>Link Unik</strong> post ini',
    'Add a member to notify' => 'Tambah pemberitahuan anggota',
    'Add tag...' => 'Tambah tag...',
    'Archived' => 'Arsip',
    'Attach Files' => 'Unggah berkas',
    'Back to stream' => 'Kembali ke feed',
    'Cancel' => 'Batal',
    'Cancel Edit' => 'Batal Ubah',
    'Change to "Private"' => 'Buat privat',
    'Change to "Public"' => 'Buat publik',
    'Comments are locked' => 'Komentar dikunci',
    'Comments are unlocked' => 'Komentar dibuka',
    'Configure' => 'Konfigurasi',
    'Confirm' => 'Konfirmasi',
    'Content' => 'Konten',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Tag Konten dengan contentcontainer_id yang tidak valid ditetapkan.',
    'Content has been moved to {spacename}' => 'Konten pindah ke {spacename}',
    'Could not find requested content!' => 'Tidak menemukan konten itu',
    'Created at:' => 'Dibuat pada:',
    'Created by me' => 'Dibuat oleh saya',
    'Creation time' => 'Waktu dibuat',
    'Delete' => 'Hapus',
    'Edit' => 'Ubah',
    'Enable' => 'Aktifkan',
    'Filter' => 'Filter',
    'I\'m involved' => 'Ada saya',
    'Invalid content id given!' => 'ID konten yang diberikan tidak valid!',
    'Invalid request method!' => 'Kesalahan metode permintaan!',
    'Invalid space selection.' => 'Pilihan ruang tidak valid.',
    'Last update' => 'Update terakhir',
    'Last updated {time}' => 'Update terakhir {time}',
    'Load more' => 'Buka lagi',
    'Lock comments' => 'Kunci komentar',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Jumlah maksimum item yang disematkan tercapai!<br>Anda hanya dapat menyematkan hingga {count} item sekaligus.',
    'Move content' => 'Pindah konten',
    'Move to archive' => 'Pindahkan ke arsip',
    'New Updates Available!' => 'Tersedia Pembaruan Baru!',
    'No matches with your selected filters!' => 'Tidak ada yang cocok dengan filter pilihan Anda!',
    'No tags found for the given query' => 'Tidak ada tag yang ditemukan untuk kueri yang diberikan',
    'None' => 'Tidak ada',
    'Nothing here yet!' => 'Belum ada apa-apa di sini!',
    'Notify members' => 'Beritahu anggota',
    'Permalink' => '@@@@',
    'Pin to top' => 'Sematkan ke atas',
    'Pinned' => 'Disematkan',
    'Private' => 'Pribadi',
    'Public' => 'Publik',
    'Select type...' => 'Pilih tipe...',
    'Specify who can see this content.' => 'Tentukan siapa saja yang dapat melihat konten ini.',
    'Submit' => 'Kirim',
    'Tag' => 'Tag',
    'Target Space' => 'Ruang Sasaran',
    'The author of this content is not allowed to create private content within the selected space.' => 'Penulis konten ini tidak diperbolehkan membuat konten pribadi di dalam ruang yang dipilih.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Penulis konten ini tidak diperbolehkan membuat konten publik di dalam ruang yang dipilih.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Pembuat konten ini tidak diizinkan membuat jenis konten ini di ruang ini.',
    'The content can\'t be moved to its current space.' => 'Konten tidak dapat dipindahkan ke ruangnya saat ini.',
    'The content has been archived.' => 'Konten tersebut telah diarsipkan.',
    'The content has been deleted.' => 'Konten telah dihapus.',
    'The content has been unarchived.' => 'Konten telah dibatalkan pengarsipannya.',
    'This action is disabled!' => 'Untuk aksi ini dinonaktifkan',
    'This space is archived.' => 'Ruang ini di arsipkan',
    'Unarchive' => 'arsipkan',
    'Updated' => 'Perbarui',
    'in' => 'pada',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Activated' => '',
    'Cannot notify the author.' => '',
    'Create as draft' => '',
    'Deleted' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
    'The given name is already in use.' => '',
    'The module {moduleName} is not enabled on the selected target space.' => '',
    'This content type can\'t be moved due to a missing module-id setting.' => '',
    'This content type can\'t be moved.' => '',
    'This space is not visible!' => '',
    'Topics' => '',
    'Turn off notifications' => '',
    'Turn on notifications' => '',
    'Unlock comments' => '',
    'Unpin' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'With attachments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
    'You do not have the permission to move this content to the given space.' => '',
    'You do not have the permission to move this content.' => '',
    'Your last edit state has been saved!' => '',
];
